==> accounts_management-0.1.6.gem: app/controllers/accounts_management/documents/invoice_entry_types_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Documents::InvoiceEntryTypesController < AccountsManagementController
    # GET /documents/invoice_entry_types
    # GET /documents/invoice_entry_types.json
    def index
      @documents_invoice_entry_types = Documents::InvoiceEntryType.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @documents_invoice_entry_types }
      end
    end

    # GET /documents/invoice_entry_types/1
    # GET /documents/invoice_entry_types/1.json
    def show
      @documents_invoice_entry_type = Documents::InvoiceEntryType.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @documents_invoice_entry_type }
      end
    end

    # GET /documents/invoice_entry_types/new
    # GET /documents/invoice_entry_types/new.json
    def new
      @documents_invoice_entry_type = Documents::InvoiceEntryType.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @documents_invoice_entry_type }
      end
    end

    # GET /documents/invoice_entry_types/1/edit
    def edit
      @documents_invoice_entry_type = Documents::InvoiceEntryType.find(params[:id])
    end

    # POST /documents/invoice_entry_types
    # POST /documents/invoice_entry_types.json
    def create
      @documents_invoice_entry_type = Documents::InvoiceEntryType.new(params[:documents_invoice_entry_type])

      respond_to do |format|
        if @documents_invoice_entry_type.save
          format.html { redirect_to @documents_invoice_entry_type, :notice => 'Invoice entry type was successfully created.' }
          format.json { render :json => @documents_invoice_entry_type, :status => :created, :location => @documents_invoice_entry_type }
        else
          format.html { render :action => "new" }
          format.json { render :json => @documents_invoice_entry_type.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /documents/invoice_entry_types/1
    # PUT /documents/invoice_entry_types/1.json
    def update
      @documents_invoice_entry_type = Documents::InvoiceEntryType.find(params[:id])

      respond_to do |format|
        if @documents_invoice_entry_type.update_attributes(params[:documents_invoice_entry_type])
          format.html { redirect_to @documents_invoice_entry_type, :notice => 'Invoice entry type was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @documents_invoice_entry_type.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /documents/invoice_entry_types/1
    # DELETE /documents/invoice_entry_types/1.json
    def destroy
      @documents_invoice_entry_type = Documents::InvoiceEntryType.find(params[:id])
      @documents_invoice_entry_type.destroy

      respond_to do |format|
        format.html { redirect_to documents_invoice_entry_types_url }
        format.json { head :no_content }
      end
    end
  end
end

==> accounts_management-0.1.7.gem: app/controllers/accounts_management/documents/invoice_entry_types_controller.rb <==
require_dependency "accounts_management/accounts_management_controller"

module AccountsManagement
  class Documents::InvoiceEntryTypesController < AccountsManagementController
    # GET /documents/invoice_entry_types
    # GET /documents/invoice_entry_types.json
    def index
      @documents_invoice_entry_types = Documents::InvoiceEntryType.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render json: @documents_invoice_entry_types }
      end
    end

    # GET /documents/invoice_entry_types/1
    # GET /documents/invoice_entry_types/1.json
    def show
      @documents_invoice_entry_type = Documents::InvoiceEntryType.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render json: @documents_invoice_entry_type }
      end
    end

    # GET /documents/invoice_entry_types/new
    # GET /documents/invoice_entry_types/new.json
    def new
      @documents_invoice_entry_type = Documents::InvoiceEntryType.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render json: @documents_invoice_entry_type }
      end
    end

    # GET /documents/invoice_entry_types/1/edit
    def edit
      @documents_invoice_entry_type = Documents::InvoiceEntryType.find(params[:id])
    end

    # POST /documents/invoice_entry_types
    # POST /documents/invoice_entry_types.json
    def create
      @documents_invoice_entry_type = Documents::InvoiceEntryType.new(params[:documents_invoice_entry_type])

      respond_to do |format|
        if @documents_invoice_entry_type.save
          format.html { redirect_to @documents_invoice_entry_type, notice: 'Invoice entry type was successfully created.' }
          format.json { render json: @documents_invoice_entry_type, status: :created, location: @documents_invoice_entry_type }
        else
          format.html { render action: "new" }
          format.json { render json: @documents_invoice_entry_type.errors, status: :unprocessable_entity }
        end
      end
    end

    # PUT /documents/invoice_entry_types/1
    # PUT /documents/invoice_entry_types/1.json
    def update
      @documents_invoice_entry_type = Documents::InvoiceEntryType.find(params[:id])

      respond_to do |format|
        if @documents_invoice_entry_type.update_attributes(params[:documents_invoice_entry_type])
          format.html { redirect_to @documents_invoice_entry_type, notice: 'Invoice entry type was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render action: "edit" }
          format.json { render json: @documents_invoice_entry_type.errors, status: :unprocessable_entity }
        end
      end
    end

    # DELETE /documents/invoice_entry_types/1
    # DELETE /documents/invoice_entry_types/1.json
    def destroy
      @documents_invoice_entry_type = Documents::InvoiceEntryType.find(params[:id])
      @documents_invoice_entry_type.destroy

      respond_to do |format|
        format.html { redirect_to documents_invoice_entry_types_url }
        format.json { head :no_content }
      end
    end
  end
end
